pub struct ClientConfig {
pub connection_string: String,
pub protocol: ClientProtocolConfig,
pub connection: ConnectionConfig,
pub network: NetworkConfig,
pub log: LogConfig,
}Expand description
Quincy client configuration.
Fields
connection_string: StringConnection string to be used to connect to a Quincy server
protocol: ClientProtocolConfigProtocol configuration (TLS or Noise)
connection: ConnectionConfigQUIC connection configuration
network: NetworkConfigNetwork configuration
log: LogConfigLogging configuration
Implementations
Sourceimpl ClientConfig
impl ClientConfig
Sourcepub fn quinn_client_config(&self) -> Result<ClientConfig>
pub fn quinn_client_config(&self) -> Result<ClientConfig>
Creates Quinn client configuration from this Quincy client configuration.
Returns
quinn::ClientConfig- the Quinn client configuration
Sourcepub fn noise_key_exchange(&self) -> Option<&NoiseKeyExchange>
pub fn noise_key_exchange(&self) -> Option<&NoiseKeyExchange>
Returns the Noise key exchange mode if the protocol is Noise, or None for TLS.