pub struct ServerConfig {Show 13 fields
pub name: String,
pub interface_name: Option<String>,
pub bind_address: IpAddr,
pub bind_port: u16,
pub reuse_socket: bool,
pub tunnel_network: IpNet,
pub users_file: PathBuf,
pub isolate_clients: bool,
pub default_bandwidth_limit: Option<Bandwidth>,
pub protocol: ServerProtocolConfig,
pub connection: ConnectionConfig,
pub log: LogConfig,
pub metrics: MetricsConfig,
}Expand description
Quincy server configuration.
Fields
name: StringThe name of the tunnel
interface_name: Option<String>Optional interface name to request for the tunnel device
bind_address: IpAddrThe address to bind the tunnel to (default = 0.0.0.0)
bind_port: u16The port to bind the tunnel to (default = 55555)
reuse_socket: boolWhether to reuse the socket (default = false)
This is useful when running multiple Quincy instances on the same port for load balancing.
Unsupported on Windows.
tunnel_network: IpNetThe network address of this tunnel (address + mask)
users_file: PathBufPath to the TOML users file for authentication
isolate_clients: boolWhether to isolate clients from each other (default = true)
default_bandwidth_limit: Option<Bandwidth>Default bandwidth limit applied to users without a per-user limit. If not set, users without a per-user limit have unlimited bandwidth.
protocol: ServerProtocolConfigProtocol configuration (TLS or Noise)
connection: ConnectionConfigMiscellaneous connection configuration
log: LogConfigLogging configuration
metrics: MetricsConfigPrometheus metrics configuration.
Implementations
Sourceimpl ServerConfig
impl ServerConfig
Sourcepub fn as_quinn_server_config(
&self,
allowed_keys: Option<AllowedNoiseKeys>,
allowed_fingerprints: Option<HashSet<String>>,
) -> Result<ServerConfig>
pub fn as_quinn_server_config( &self, allowed_keys: Option<AllowedNoiseKeys>, allowed_fingerprints: Option<HashSet<String>>, ) -> Result<ServerConfig>
Creates Quinn server configuration from this Quincy tunnel configuration.
Arguments
allowed_keys- for Noise mode, the set of allowed client public keys. For TLS mode, passNone.allowed_fingerprints- for TLS mode, the set of allowed client certificate fingerprints. For Noise mode, passNone.
Returns
quinn::ServerConfig- the Quinn server configuration
Sourcepub fn noise_key_exchange(&self) -> Option<&NoiseKeyExchange>
pub fn noise_key_exchange(&self) -> Option<&NoiseKeyExchange>
Returns the Noise key exchange mode if the protocol is Noise, or None for TLS.